%define anolis_release 3
Name:           geoclue2
Version:        2.7.0
Release:        %{anolis_release}%{dist}
Summary:        Geolocation service

License:        GPLv2+
URL:            http://www.freedesktop.org/wiki/Software/GeoClue/
Source0:        https://gitlab.freedesktop.org/geoclue/geoclue/-/archive/%{version}/geoclue-%{version}.tar.gz

BuildRequires:  vala
BuildRequires:  meson
BuildRequires:  gtk-doc
BuildRequires:  gettext
BuildRequires:  systemd
BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
BuildRequires:  libsoup3-devel
BuildRequires:  avahi-glib-devel
BuildRequires:  ModemManager-glib-devel
BuildRequires:  gobject-introspection-devel
Requires:       dbus
Requires(pre):  shadow-utils

Obsoletes:      geoclue2-server < 2.1.8

Obsoletes:      geoclue        < 0.12.99
Obsoletes:      geoclue-gui    < 0.12.99
Obsoletes:      geoclue-devel  < 0.12.99
Obsoletes:      geoclue-gypsy  < 0.12.99
Obsoletes:      geoclue-gsmloc < 0.12.99

%description
Geoclue2 is a location-based service that provides access to geographical
information in Linux-based operating systems. It is an open-source framework
that enables applications to access location-based data from various sources
such as GPS receivers, Wi-Fi, GSM/CDMA, and IP address geolocation.

Geoclue2 provides an API for developers to access location-based data in a
simple and consistent way. This API allows applications to query Geoclue2
for the current location of the system, as well as request notifications of
 location changes.

One of the key features of Geoclue2 is its support for privacy and security.
It allows users to control access to their location data by providing a
mechanism to configure which applications are allowed to access their location
information. Additionally, Geoclue2 supports sandboxing, which limits access
to location data only to applications with explicit permission from the user.

Overall, Geoclue2 is an essential tool for developers who require access
to location-based data in their Linux applications. Its support for various
location sources, consistent API, and focus on privacy and security make it
a valuable addition to the Linux ecosystem.

%package        libs
Summary:        Geoclue client library
License:        LGPLv2+
Recommends:     %{name} = %{version}-%{release}

%description    libs
The %{name}-libs package contains a convenience library to interact with
Geoclue service.

%package        demos
Summary:        Demo applications for %{name}
Recommends:     %{name} = %{version}-%{release}
BuildRequires:  libnotify-devel

%description    demos
The %{name}-demos package contains demo applications that use %{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
The %{name}-devel package contains files for developing applications that
use %{name}.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1 -n geoclue-%{version}

%build
%meson -Ddbus-srv-user=geoclue
%meson_build


%install
%meson_install

# Home directory for the 'geoclue' user
mkdir -p $RPM_BUILD_ROOT/var/lib/geoclue

%generate_compatibility_deps

%pre
# Update the home directory for existing users
getent passwd geoclue >/dev/null && \
    usermod -d /var/lib/geoclue geoclue &>/dev/null
# Create a new user and group if they don't exist
getent group geoclue >/dev/null || groupadd -r geoclue
getent passwd geoclue >/dev/null || \
    useradd -r -g geoclue -d /var/lib/geoclue -s /sbin/nologin \
    -c "User for geoclue" geoclue
exit 0

%post
%systemd_post geoclue.service

%preun
%systemd_preun geoclue.service

%postun
%systemd_postun_with_restart geoclue.service


%files
%dir %{abidir}
%{_libexecdir}/geoclue
%{_mandir}/man5/geoclue.5*
%{_unitdir}/geoclue.service
%{abidir}/libgeoclue-2.dump
%config %{_sysconfdir}/geoclue/
%dir %{_libexecdir}/geoclue-2.0
%dir %{_libexecdir}/geoclue-2.0/demos
%{_libexecdir}/geoclue-2.0/demos/agent
%attr(755,geoclue,geoclue) %dir /var/lib/geoclue
%{_datadir}/applications/geoclue-demo-agent.desktop
%{_sysconfdir}/xdg/autostart/geoclue-demo-agent.desktop
%{_datadir}/polkit-1/rules.d/org.freedesktop.GeoClue2.rules
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.conf
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.Agent.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.GeoClue2.service
%license COPYING

%files libs
%dir %{abidir}
%{abidir}/libgeoclue-2.dump
%{_libdir}/libgeoclue-2.so.0*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Geoclue-2.0.typelib
%license COPYING.LIB

%files demos
%{_libexecdir}/geoclue-2.0/demos/where-am-i
%{_datadir}/applications/geoclue-where-am-i.desktop

%files devel
%dir %{_datadir}/vala
%dir %{_datadir}/gir-1.0
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/vala/vapi
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/geoclue/
%{_datadir}/gir-1.0/Geoclue-2.0.gir
%{_datadir}/gtk-doc/html/libgeoclue/
%{_datadir}/vala/vapi/libgeoclue-2.0.*
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2*.xml
%{_includedir}/libgeoclue-2.0/
%{_libdir}/libgeoclue-2.so
%{_libdir}/pkgconfig/geoclue-2.0.pc
%{_libdir}/pkgconfig/libgeoclue-2.0.pc

%files doc
%doc HACKING.md  NEWS  README.md 

%changelog 
* Tue Apr 30 2024 Bo Ren <rb01097748@alibaba-inc.com> - 2.7.0-3
- Rebuild for anolis23.1

* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.7.0-2
- Optimize the spec

* Thu Apr 06 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> -2.7.0-1
- update to 2.7.0 and switch to libsoup3

* Mon Feb 27 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.6.0-2
- Add doc package and abi file

* Wed Apr 13 2022 Zhongling He <zhonglingh@linux.alibaba.com> 2.6.0-1
- Init package from upstream v2.6.0
